View source: R/nhpp_functions.R
| path_hamming | R Documentation |
Calculates the hamming distance between states for a given path.
path_hamming(Path)
Path |
data.frame. A tibble with state information about a given path (from root to a given node). The tibble is the output obtained from the get_states_path function. The columns give information on state changes, time spent on each state, and edge IDs. |
The input tibble with two additional columns giving information on absolute and normalized hamming distances.
Sergei Tarasov
Internal function. Not exported.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.