stack2: Stack two discrete stochastic character map lists; x and y...

View source: R/paramo_functions.R

stack2R Documentation

Stack two discrete stochastic character map lists; x and y are the list of state names (i.e. maps).

Description

Stack two discrete stochastic character map lists; x and y are the list of state names (i.e. maps).

Usage

stack2(x, y)

Arguments

x

list. A list of state names.

y

list. A list of state names.

Internal function. Not exported.

Author(s)

Sergei Tarasov


ontophylo documentation built on May 29, 2024, 9:57 a.m.